## pyQTL

pyQTL is a python module for analyzing and visualizing quantitative trait loci (QTL) data.


### Install
You can install pyQTL using pip:
```
pip3 install qtl
```
or directly from this repository:
```
$ git clone git@github.com:broadinstitute/pyqtl.git
$ cd pyqtl
# set up virtual environment and install
$ virtualenv venv
$ source venv/bin/activate
(venv)$ pip install -e .
```